<?php
/*
Plugin Name: 投稿・固定ページ内の検索
Description: 指定した語句がどの投稿や固定ページで使われているかを検索して表示するプラグイン
Version: 1.0
Author: 安井 直樹
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // 直接アクセスを防ぐ
}

// 管理画面にメニューを追加
add_action( 'admin_menu', 'Toukou_Kotei_Kensaku_menu' );
function Toukou_Kotei_Kensaku_menu() {
    add_menu_page(
        '投稿・固定ページ内の検索',
        '投稿・固定ページ内の検索',
        'manage_options',
        'Toukou-Kotei-Kensaku',
        'Toukou_Kotei_Kensaku_page',
        'dashicons-search',
        20
    );
}

// メインページの内容
function Toukou_Kotei_Kensaku_page() {
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // フォーム処理
    if ( isset( $_POST['image_url'] ) ) {
        $image_url = sanitize_text_field( $_POST['image_url'] );
        $results = image_usage_finder_search( $image_url );
    }

    ?>
    <div class="wrap">
        <h1>投稿・固定ページ内の検索</h1>
        <form method="post">
            <label for="image_url">検索したい語句を入力してください:</label>
            <input type="text" name="image_url" id="image_url" style="width: 50%;" required>
            <button type="submit" class="button button-primary">検索</button>
        </form>

        <?php if ( isset( $results ) ): ?>
            <h2>検索結果</h2>
            <?php if ( empty( $results ) ): ?>
                <p>該当するページが見つかりませんでした。</p>
            <?php else: ?>
                <ul>
                    <?php foreach ( $results as $result ): ?>
                        <li>投稿ID：
                                <a href="<?php echo get_edit_post_link( $result->ID ); ?>" target="_blank">
                                <?php echo esc_html( $result->ID ); ?>
                                </a>
                            投稿タイトル：
                                <a href="<?php echo get_edit_post_link( $result->ID ); ?>" target="_blank">
                                <?php echo esc_html( $result->post_title ); ?>
                                </a>
                        </li>
                    <?php endforeach; ?>
                </ul>
            <?php endif; ?>
        <?php endif; ?>
    </div>
    <div>
        <h2>使い方</h2>
        <table>
            <ul>
                <li>検索欄に検索語句を打ち込み、検索ボタンを押してください。</li>
                <li>入力語句が含まれている投稿ページおよび固定ページが表示されます。</li>
                <li>画像URLを入力すれば、画像が使われているページが表示されます。</li>
            </ul>
        </table>
    </div>
    <?php
}

// 画像URLを検索
function image_usage_finder_search( $image_url ) {
    global $wpdb;


    // wp_postsテーブルの投稿と固定ページを検索
    $query = "
        SELECT ID, post_title
        FROM {$wpdb->posts}
        WHERE post_type IN ('post', 'page')
        AND post_content LIKE %s
    ";
    $like = '%' . $wpdb->esc_like( $image_url ) . '%';
    $results = $wpdb->get_results( $wpdb->prepare($query, $like) );

    return $results;
}
